"use strict";

var _interopRequireDefault = require("@babel/runtime-corejs2/helpers/interopRequireDefault");

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.createRouterProxy = createRouterProxy;

var _objectSpread2 = _interopRequireDefault(require("@babel/runtime-corejs2/helpers/objectSpread"));

var _extends2 = _interopRequireDefault(require("@babel/runtime-corejs2/helpers/extends"));

var _react = _interopRequireDefault(require("react"));

var _reactRouter = require("react-router");

var _LocationInterceptor = _interopRequireDefault(require("./LocationInterceptor"));

var _url = _interopRequireDefault(require("url"));

function createRouterProxy() {
  var RouterProxy = function RouterProxy(props) {
    var nextProxy = props.nextProxy,
        fixture = props.fixture,
        onFixtureUpdate = props.onFixtureUpdate;
    var NextProxy = nextProxy.value,
        next = nextProxy.next;
    var route = fixture.route,
        url = fixture.url,
        locationState = fixture.locationState,
        provideRouterProps = fixture.provideRouterProps;

    var nextProxyEl = _react.default.createElement(NextProxy, (0, _extends2.default)({}, props, {
      nextProxy: next()
    }));

    if (locationState && !url) {
      throw new Error('Must provide a url in fixture to use locationState');
    }

    if (!url) {
      return nextProxyEl;
    }

    var handleUrlChange = function handleUrlChange(url) {
      onFixtureUpdate({
        url: url
      });
    };

    var handleLocationStateChange = function handleLocationStateChange(locationState) {
      onFixtureUpdate({
        locationState: locationState
      });
    };

    var location = buildLocation(url, locationState);
    return (// keyLength=0 generates empty "" history keys, leading to deterministic
      // test snapshots https://github.com/react-cosmos/react-cosmos/pull/803
      _react.default.createElement(_reactRouter.MemoryRouter, {
        keyLength: 0,
        initialEntries: [location]
      }, _react.default.createElement(_LocationInterceptor.default, {
        onUrlChange: handleUrlChange,
        onLocationStateChange: handleLocationStateChange
      }, route ? _react.default.createElement(_reactRouter.Route, {
        path: route,
        render: function render(routerProps) {
          if (provideRouterProps) {
            var newProxyProps = (0, _objectSpread2.default)({}, props, {
              fixture: (0, _objectSpread2.default)({}, props.fixture, {
                props: (0, _objectSpread2.default)({}, props.fixture.props, routerProps)
              })
            });
            return _react.default.createElement(NextProxy, (0, _extends2.default)({}, newProxyProps, {
              nextProxy: next()
            }));
          }

          return nextProxyEl;
        }
      }) : nextProxyEl))
    );
  };

  return RouterProxy;
}

function buildLocation(url, locationState) {
  var _urlParser$parse = _url.default.parse(url),
      pathname = _urlParser$parse.pathname,
      search = _urlParser$parse.search,
      hash = _urlParser$parse.hash;

  return {
    pathname: pathname,
    search: search,
    hash: hash,
    key: 'mocked',
    state: locationState
  };
}